@@ -7,11 +7,11 @@ our @ISA = qw( Test::Database::Driver );
 
 use File::Spec;
 
-sub create_database {
-    my ( $class, $dbname ) = @_;
+__PACKAGE__->init();
 
+sub create_database {
+    my ( $class, $config, $dbname ) = @_;
     my $dbfile = File::Spec->catfile( $class->base_dir(), $dbname );
-    mkdir $class->base_dir() if !-e $class->base_dir();
 
     return Test::Database::Handle->new( dsn => "dbi:SQLite:dbname=$dbfile", );
 }
